netapp_ontap.models.nfs_service_access_cache_config API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_access_cache_config`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceAccessCacheConfigSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceAccessCacheConfig object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `harvest_timeout: Size GET POST PATCH`

    Specifies the time after which an entry is deleted from the access cache, if unused.

    Example: 3600

  `is_dns_ttl_enabled: bool GET POST PATCH`

    Specifies whether Dns TTL is enabled.

  `ttl_failure: Size GET POST PATCH`

    Specifies the time to live value for entries for which a failure was encountered, in seconds.

    Example: 1

  `ttl_negative: Size GET POST PATCH`

    Specifies the time to live value of a negative access cache, in seconds.

    Example: 30

  `ttl_positive: Size GET POST PATCH`

    Specifies the time to live value of a positive access cache, in seconds.

    Example: 60